ExpandArrowWidget class

This widget is used in both ExpandChild & ExpandText widgets to show the hidden information to the user. It posses an animation parameter. Most widget parameters are customizable.

Inheritance

Constructors

ExpandArrowWidget({Key? key, String? collapsedHint, String? expandedHint, required Animation<double> animation, EdgeInsets? padding, void onTap()?, Color? arrowColor, double? arrowSize, IconData? icon, TextStyle? hintTextStyle, ExpandArrowStyle? expandArrowStyle, bool capitalArrowtext = true})
const

Properties

animation → Animation<double>
Controlls the arrow's fluid(TM) animation for the arrow's rotation.
final
arrowColor → Color?
Defines arrow's color.
final
arrowSize → double?
Defines arrow's size. Default is 30.
final
capitalArrowtext → bool
Autocapitalise tooltip text.
final
collapsedHint → String?
String used as a tooltip when the widget is minimized. Default value set to MaterialLocalizations.of(context).collapsedIconTapHint.
final
expandArrowStyle → ExpandArrowStyle?
Defines arrow rendering style. Default is ExpandArrowStyle.icon.
final
expandedHint → String?
String used as a tooltip when the widget is maximazed. Default value set to MaterialLocalizations.of(context).expandedIconTapHint.
final
hashCode → int
The hash code for this object.
no setterinherited
hintTextStyle → TextStyle?
Style of the displayed message.
final
icon → IconData?
Icon that will be used instead of an arrow. Default is Icons.expand_more.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap → void Function()?
Callback to controll what happeds when the arrow is clicked.
final
padding → EdgeInsets?
Defines padding value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited