ExpandChildWidget class

This widget unfolds a hidden widget to the user, called child. This action is performed when the user clicks the 'expand' arrow.

Inheritance

Constructors

ExpandChildWidget({Key? key, String? collapsedHint, String? expandedHint, EdgeInsets? arrowPadding, Color? arrowColor, double arrowSize = 30, IconData? icon, TextStyle? hintTextStyle, ExpandArrowStyle expandArrowStyle = ExpandArrowStyle.icon, bool capitalArrowtext = true, bool expand = false, Duration animationDuration = _kExpand, Widget? child, bool hideArrowOnExpanded = false})
const

Properties

animationDuration → Duration
How long the expanding animation takes. Default is 260ms.
final
arrowColor → Color?
Color of the arrow widget. Defaults to the caption text style color.
final
arrowPadding → EdgeInsets?
Defines padding value.
final
arrowSize → double
Size of the arrow widget. Default is 30.
final
capitalArrowtext → bool
Autocapitalise tooltip text.
final
child → Widget?
This widget will be displayed if the user clicks the 'expand' arrow.
final
collapsedHint → String?
Message used as a tooltip when the widget is minimized. Default value set to MaterialLocalizations.of(context).collapsedIconTapHint.
final
expand → bool
Ability to expand from init
final
expandArrowStyle → ExpandArrowStyle
Defines arrow rendering style.
final
expandedHint → String?
Message used as a tooltip when the widget is maximazed. Default value set to MaterialLocalizations.of(context).expandedIconTapHint.
final
hashCode → int
The hash code for this object.
no setterinherited
hideArrowOnExpanded → bool
Ability to hide arrow from display when content is expanded.
final
hintTextStyle → TextStyle?
Style of the displayed message.
final
icon → IconData?
Icon that will be used instead of an arrow. Default is Icons.expand_more.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ExpandChildWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited